@@ -11,9 +11,9 @@ from pycfmodel.model.resources.kms_key import KMSKey
 from pycfmodel.model.resources.opensearch_domain import OpenSearchDomain
 from pycfmodel.model.resources.s3_bucket import S3Bucket
 from pycfmodel.model.resources.s3_bucket_policy import S3BucketPolicy
-from pycfmodel.model.resources.security_group import SecurityGroup
+from pycfmodel.model.resources.security_group import RDSDBSecurityGroup, SecurityGroup
 from pycfmodel.model.resources.security_group_egress import SecurityGroupEgress
-from pycfmodel.model.resources.security_group_ingress import SecurityGroupIngress
+from pycfmodel.model.resources.security_group_ingress import RDSDBSecurityGroupIngress, SecurityGroupIngress
 from pycfmodel.model.resources.sns_topic_policy import SNSTopicPolicy
 from pycfmodel.model.resources.sqs_queue_policy import SQSQueuePolicy
 
@@ -27,6 +27,8 @@ ResourceModels = Union[
     IAMUser,
     KMSKey,
     OpenSearchDomain,
+    RDSDBSecurityGroup,
+    RDSDBSecurityGroupIngress,
     S3Bucket,
     S3BucketPolicy,
     SecurityGroup,
